@@ -2,7 +2,7 @@ package Resource::Silo::Metadata;
 
 use strict;
 use warnings;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 NAME
 
@@ -57,12 +57,13 @@ my %known_args = (
     argument        => 1,
     class           => 1,
     dependencies    => 1,
-    derivative      => 1,
+    derived         => 1,
     cleanup         => 1,
     cleanup_order   => 1,
     fork_cleanup    => 1,
     ignore_cache    => 1,
     init            => 1,
+    literal         => 1,
     preload         => 1,
     require         => 1,
 );
@@ -100,6 +101,15 @@ sub add {
                 if @bad;
     };
 
+    if (defined (my $value = $spec{literal})) {
+        defined $spec{$_}
+            and croak "resource '$name': 'literal' is incompatible with '$_'"
+                for qw( init class argument );
+        $spec{init} = sub { $value };
+        $spec{dependencies} //= [];
+        $spec{derived}      //= 1;
+    };
+
     _make_init_class($self, $name, \%spec)
         if (defined $spec{class});
 
